@@ -1,7 +1,7 @@
 package App::ListOrgHeadlines;
 
-our $DATE = '2015-01-03'; # DATE
-our $VERSION = '0.23'; # VERSION
+our $DATE = '2015-03-10'; # DATE
+our $VERSION = '0.24'; # VERSION
 
 use 5.010001;
 use strict;
@@ -344,10 +344,7 @@ sub list_org_headlines {
         $res = [map {$_->[0]} @res];
     }
 
-    [200, "OK", $res, {result_format_options=>{
-        "text"        => {list_max_columns=>1},
-        "text-pretty" => {list_max_columns=>1},
-    }}];
+    [200, "OK", $res, {format_options=>{"any"=> {list_max_columns=>1}}}];
 }
 
 1;
@@ -365,7 +362,7 @@ App::ListOrgHeadlines - List all headlines in all Org files
 
 =head1 VERSION
 
-This document describes version 0.23 of App::ListOrgHeadlines (from Perl distribution App-OrgUtils), released on 2015-01-03.
+This document describes version 0.24 of App::ListOrgHeadlines (from Perl distribution App-OrgUtils), released on 2015-03-10.
 
 =head1 SYNOPSIS
 
@@ -375,8 +372,6 @@ This document describes version 0.23 of App::ListOrgHeadlines (from Perl distrib
 
 =head1 FUNCTIONS
 
-None are exported, but they are exportable.
-
 
 =head2 list_org_headlines(%args) -> [status, msg, result, meta]
 
@@ -490,13 +485,14 @@ element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUtils>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-App-OrgUtils>.
+Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.
 
 =head1 BUGS
 
